@@ -15,6 +15,7 @@
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
 use snarkvm_algorithms::traits::{CommitmentScheme, EncryptionScheme, SignatureScheme, CRH, PRF};
+use snarkvm_curves::PairingEngine;
 use snarkvm_fields::PrimeField;
 use snarkvm_gadgets::traits::algorithms::{
     CRHGadget,
@@ -25,61 +26,67 @@ use snarkvm_gadgets::traits::algorithms::{
 };
 
 pub trait DPCComponents: 'static + Sized {
+    const NETWORK_ID: u8;
+
     const NUM_INPUT_RECORDS: usize;
     const NUM_OUTPUT_RECORDS: usize;
+    const NUM_TOTAL_RECORDS: usize = Self::NUM_INPUT_RECORDS + Self::NUM_OUTPUT_RECORDS;
 
-    type InnerField: PrimeField;
-    type OuterField: PrimeField;
+    type InnerCurve: PairingEngine;
+    type OuterCurve: PairingEngine;
+
+    type InnerScalarField: PrimeField;
+    type OuterScalarField: PrimeField;
 
     /// Encryption scheme for account records.
     type AccountEncryption: EncryptionScheme;
-    type AccountEncryptionGadget: EncryptionGadget<Self::AccountEncryption, Self::InnerField>;
+    type AccountEncryptionGadget: EncryptionGadget<Self::AccountEncryption, Self::InnerScalarField>;
 
-    /// Commitment scheme for account contents. Invoked only over `Self::InnerField`.
+    /// Commitment scheme for account contents. Invoked only over `Self::InnerScalarField`.
     type AccountCommitment: CommitmentScheme;
-    type AccountCommitmentGadget: CommitmentGadget<Self::AccountCommitment, Self::InnerField>;
+    type AccountCommitmentGadget: CommitmentGadget<Self::AccountCommitment, Self::InnerScalarField>;
 
     /// Signature scheme for delegated compute.
     type AccountSignature: SignatureScheme;
-    type AccountSignatureGadget: SignaturePublicKeyRandomizationGadget<Self::AccountSignature, Self::InnerField>;
+    type AccountSignatureGadget: SignaturePublicKeyRandomizationGadget<Self::AccountSignature, Self::InnerScalarField>;
 
     /// CRH for the encrypted record.
     type EncryptedRecordCRH: CRH;
-    type EncryptedRecordCRHGadget: CRHGadget<Self::EncryptedRecordCRH, Self::InnerField>;
+    type EncryptedRecordCRHGadget: CRHGadget<Self::EncryptedRecordCRH, Self::InnerScalarField>;
 
     /// CRH for hash of the `Self::InnerSNARK` verification keys.
     /// This is invoked only on the larger curve.
     type InnerCircuitIDCRH: CRH;
-    type InnerCircuitIDCRHGadget: CRHGadget<Self::InnerCircuitIDCRH, Self::OuterField>;
+    type InnerCircuitIDCRHGadget: CRHGadget<Self::InnerCircuitIDCRH, Self::OuterScalarField>;
 
     /// CRH and commitment scheme for committing to program input. Invoked inside
     /// `Self::InnerSNARK` and every program SNARK.
     type LocalDataCRH: CRH;
-    type LocalDataCRHGadget: CRHGadget<Self::LocalDataCRH, Self::InnerField>;
+    type LocalDataCRHGadget: CRHGadget<Self::LocalDataCRH, Self::InnerScalarField>;
     type LocalDataCommitment: CommitmentScheme;
-    type LocalDataCommitmentGadget: CommitmentGadget<Self::LocalDataCommitment, Self::InnerField>;
+    type LocalDataCommitmentGadget: CommitmentGadget<Self::LocalDataCommitment, Self::InnerScalarField>;
 
     /// CRH for hashes of birth and death verification keys.
     /// This is invoked only on the larger curve.
     type ProgramVerificationKeyCRH: CRH;
-    type ProgramVerificationKeyCRHGadget: CRHGadget<Self::ProgramVerificationKeyCRH, Self::OuterField>;
+    type ProgramVerificationKeyCRHGadget: CRHGadget<Self::ProgramVerificationKeyCRH, Self::OuterScalarField>;
 
     /// Commitment scheme for committing to hashes of birth and death verification keys
     type ProgramVerificationKeyCommitment: CommitmentScheme;
     /// Used to commit to hashes of verification keys on the smaller curve and to decommit hashes
     /// of verification keys on the larger curve
-    type ProgramVerificationKeyCommitmentGadget: CommitmentGadget<Self::ProgramVerificationKeyCommitment, Self::InnerField>
-        + CommitmentGadget<Self::ProgramVerificationKeyCommitment, Self::OuterField>;
+    type ProgramVerificationKeyCommitmentGadget: CommitmentGadget<Self::ProgramVerificationKeyCommitment, Self::InnerScalarField>
+        + CommitmentGadget<Self::ProgramVerificationKeyCommitment, Self::OuterScalarField>;
 
-    /// PRF for computing serial numbers. Invoked only over `Self::InnerField`.
+    /// PRF for computing serial numbers. Invoked only over `Self::InnerScalarField`.
     type PRF: PRF;
-    type PRFGadget: PRFGadget<Self::PRF, Self::InnerField>;
+    type PRFGadget: PRFGadget<Self::PRF, Self::InnerScalarField>;
 
-    /// Commitment scheme for record contents. Invoked only over `Self::InnerField`.
+    /// Commitment scheme for record contents. Invoked only over `Self::InnerScalarField`.
     type RecordCommitment: CommitmentScheme;
-    type RecordCommitmentGadget: CommitmentGadget<Self::RecordCommitment, Self::InnerField>;
+    type RecordCommitmentGadget: CommitmentGadget<Self::RecordCommitment, Self::InnerScalarField>;
 
-    /// CRH for computing the serial number nonce. Invoked only over `Self::InnerField`.
+    /// CRH for computing the serial number nonce. Invoked only over `Self::InnerScalarField`.
     type SerialNumberNonceCRH: CRH;
-    type SerialNumberNonceCRHGadget: CRHGadget<Self::SerialNumberNonceCRH, Self::InnerField>;
+    type SerialNumberNonceCRHGadget: CRHGadget<Self::SerialNumberNonceCRH, Self::InnerScalarField>;
 }
